// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package xflags

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

type CmdTestHelp1 struct {
	A    bool `short:"a" description:"Message A"`
	Sub1 struct {
		B    bool `short:"b" description:"Message B"`
		Sub2 struct {
			C    bool `short:"c" description:"Message C"`
			Sub3 struct {
				D bool `short:"d" description:"Message D"`
			} `command:"sub3"`
			Sub4 struct {
				E bool `short:"e" description:"Message E"`
			} `command:"sub4"`
		} `command:"sub2"`
	} `command:"sub1"`
	aa int `short:"x" description:"Message X"`
}

func TestGetHelp(t *testing.T) {

	tables := []struct {
		name      string
		args      []string
		substring string
	}{
		{"test1", []string{"sub1", "--help"}, "Usage: test1 sub1 [global options] [command] [arguments]"},
		{"test1", []string{"xsd", "help"}, "Usage: test1 [global options] [command] [arguments]"},
		{"test2", []string{"sub1", "sub2"}, "Usage: test2 sub1 sub2 [global options] [command] [arguments]"},
	}

	for _, table := range tables {
		t.Run(table.name, func(t *testing.T) {
			s := New(table.name, CmdTestHelp1{})
			s.Parse(table.args)
			help := s.Help()
			assert.NotEmpty(t, help)
			assert.Contains(t, help, table.substring)
		})
	}

}
